@@ -1,6 +1,5 @@
 from myst.client import Client
-
-from ...models.user_get import UserGet
+from myst.openapi.models.user_get import UserGet
 
 
 def request_sync(client: Client, uuid: str) -> UserGet:
