@@ -1,9 +1,10 @@
-from typing import Any, Optional
+from typing import Dict, List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
+from myst.openapi.models.time_dataset import TimeDataset
 
 
 class ModelFitResultGet(base_model.BaseModel):
@@ -18,5 +19,5 @@ class ModelFitResultGet(base_model.BaseModel):
     end_time: str
     as_of_time: str
     fit_state_url: str
-    inputs: Any
+    inputs: Dict[str, Optional[List[TimeDataset]]]
     update_time: Optional[str] = None
